==> jc-1.4.0.tar.gz: scm/scmCodeAttr.h <==
// class scm.scmCodeAttr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 3a6aabca192bfc49 scm_scmCodeAttr

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmCodeAttr_H_
#define _JC_scm_scmCodeAttr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmCodeAttr$sub_refs	_jc_scm_scmCodeAttr$sub_refs;
typedef struct _jc_scm_scmCodeAttr$sub_nonrefs	_jc_scm_scmCodeAttr$sub_nonrefs;
typedef struct _jc_scm_scmCodeAttr$refs	_jc_scm_scmCodeAttr$refs;
typedef struct _jc_scm_scmCodeAttr$nonrefs	_jc_scm_scmCodeAttr$nonrefs;
typedef struct _jc_scm_scmCodeAttr$object	_jc_scm_scmCodeAttr$object;

typedef const struct _jc_scm_scmCodeAttr$vmethods	_jc_scm_scmCodeAttr$vmethods;
typedef const struct _jc_scm_scmCodeAttr$vtable	_jc_scm_scmCodeAttr$vtable;
typedef const struct _jc_scm_scmCodeAttr$vtype	_jc_scm_scmCodeAttr$vtype;

// Constructors
extern void _jc_scm_scmCodeAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmCodeAttr$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmCodeAttr$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmCodeAttr$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmCodeAttr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmCodeAttr$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmCodeAttr$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmCodeAttr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmCodeAttr$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmCodeAttr$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmCodeAttr$object *);
};

// Vtable
struct _jc_scm_scmCodeAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmCodeAttr$vmethods	scm_scmCodeAttr;
};

// Vtype
struct _jc_scm_scmCodeAttr$vtype {
	_jc_type			type;
	_jc_scm_scmCodeAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmCodeAttr$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmCodeAttr$refs {
    _jc_scm_scmCodeAttr$sub_refs	scm_scmCodeAttr;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmCodeAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmCodeAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmCodeAttr$sub_nonrefs	scm_scmCodeAttr;
};

// Object instance structure
struct _jc_scm_scmCodeAttr$object {
	_jc_scm_scmCodeAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmCodeAttr$vtype	*vtype;
	_jc_scm_scmCodeAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmCodeAttr$vtype _jc_scm_scmCodeAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmCodeAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmCodeAttr$class_object;

#endif	/* _JC_scm_scmCodeAttr_H_ */

==> jc-1.4.6.tar.gz: scm/scmCodeAttr.h <==
// class scm.scmCodeAttr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 3a6aabca192bfc49 scm_scmCodeAttr

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmCodeAttr_H_
#define _JC_scm_scmCodeAttr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmCodeAttr$sub_refs	_jc_scm_scmCodeAttr$sub_refs;
typedef struct _jc_scm_scmCodeAttr$sub_nonrefs	_jc_scm_scmCodeAttr$sub_nonrefs;
typedef struct _jc_scm_scmCodeAttr$refs	_jc_scm_scmCodeAttr$refs;
typedef struct _jc_scm_scmCodeAttr$nonrefs	_jc_scm_scmCodeAttr$nonrefs;
typedef struct _jc_scm_scmCodeAttr$object	_jc_scm_scmCodeAttr$object;

typedef const struct _jc_scm_scmCodeAttr$vmethods	_jc_scm_scmCodeAttr$vmethods;
typedef const struct _jc_scm_scmCodeAttr$vtable	_jc_scm_scmCodeAttr$vtable;
typedef const struct _jc_scm_scmCodeAttr$vtype	_jc_scm_scmCodeAttr$vtype;

// Constructors
extern void _jc_scm_scmCodeAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmCodeAttr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmCodeAttr$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmCodeAttr$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmCodeAttr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmCodeAttr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmCodeAttr$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmCodeAttr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmCodeAttr$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmCodeAttr$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmCodeAttr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmCodeAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmCodeAttr$vmethods	scm_scmCodeAttr;
};

// Vtype
struct _jc_scm_scmCodeAttr$vtype {
	_jc_type			type;
	_jc_scm_scmCodeAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmCodeAttr$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmCodeAttr$refs {
    _jc_scm_scmCodeAttr$sub_refs	scm_scmCodeAttr;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmCodeAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmCodeAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmCodeAttr$sub_nonrefs	scm_scmCodeAttr;
};

// Object instance structure
struct _jc_scm_scmCodeAttr$object {
	_jc_scm_scmCodeAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmCodeAttr$vtype	*vtype;
	_jc_scm_scmCodeAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmCodeAttr$vtype _jc_scm_scmCodeAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmCodeAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmCodeAttr$class_object;

#endif	/* _JC_scm_scmCodeAttr_H_ */
